#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const fs_extra_1 = require("fs-extra");
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const commander_1 = __importDefault(require("commander"));
const inquirer_1 = __importDefault(require("inquirer"));
const utils_1 = require("../utils");
const package_json_1 = __importDefault(require("../../../package.json"));
const readFile = util_1.promisify(fs_1.default.readFile);
let argName;
commander_1.default
    .version(package_json_1.default.version)
    .arguments('[name]')
    .action((name) => (argName = name))
    .option('-t, --type <type>', 'type of the component (normal|stateless|pure)', utils_1.convertTypeArg)
    .option('-m, --messages', 'whether to generate i18n messages')
    .parse(process.argv);
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        const classTemplate = yield readFile(require.resolve('./class.tsx.hbs'));
        const messagesTemplate = yield readFile(require.resolve('./messages.ts.hbs'));
        const statelessTemplate = yield readFile(require.resolve('./stateless.tsx.hbs'));
        const storiesTemplate = yield readFile(require.resolve('./stories.tsx.hbs'));
        const testTemplate = yield readFile(require.resolve('./test.tsx.hbs'));
        const questions = [];
        let type = commander_1.default.type;
        if (!type) {
            questions.push({
                type: 'list',
                name: 'type',
                message: 'Select the type of the component',
                default: 'React.PureComponent',
                choices: ['Stateless Function', 'React.PureComponent', 'React.Component'],
            });
        }
        let name = argName;
        if (!name) {
            questions.push({
                name: 'name',
                message: 'What should it be called?',
                validate: (value) => {
                    if (/.+/.test(value)) {
                        return utils_1.componentExists(value)
                            ? 'A component or container with this name already exists'
                            : true;
                    }
                    return 'The name is required';
                },
            });
        }
        let wantMessages = commander_1.default.messages;
        if (wantMessages === undefined) {
            questions.push({
                type: 'confirm',
                name: 'wantMessages',
                default: true,
                message: 'Do you want i18n messages (i.e., will this component use text)?',
            });
        }
        if (questions.length > 0) {
            const answers = yield inquirer_1.default.prompt(questions);
            if (answers.type) {
                type = answers.type;
            }
            if (answers.name) {
                name = answers.name;
            }
            if (answers.wantMessages !== undefined) {
                wantMessages = answers.wantMessages;
            }
        }
        const context = {
            name,
            type,
            wantMessages,
        };
        const componentDir = path_1.default.resolve(process.cwd(), `src/components/${name}`);
        yield fs_extra_1.mkdirs(path_1.default.resolve(componentDir, 'stories'));
        yield fs_extra_1.mkdirs(path_1.default.resolve(componentDir, 'tests'));
        if (type === 'Stateless Function') {
            yield utils_1.renderTemplate(statelessTemplate, path_1.default.resolve(componentDir, 'index.tsx'), context);
        }
        else {
            yield utils_1.renderTemplate(classTemplate, path_1.default.resolve(componentDir, 'index.tsx'), context);
        }
        yield utils_1.renderTemplate(testTemplate, path_1.default.resolve(componentDir, 'tests/index.test.tsx'), context);
        yield utils_1.renderTemplate(storiesTemplate, path_1.default.resolve(componentDir, 'stories/index.tsx'), context);
        if (wantMessages) {
            yield utils_1.renderTemplate(messagesTemplate, path_1.default.resolve(componentDir, 'messages.ts'), context);
        }
    });
}
run()
    .then(() => {
    process.exit(0);
})
    .catch((err) => {
    console.log('Error running script.', err);
    process.exit(1);
});
//# sourceMappingURL=index.js.map