"use strict";
/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const handlebars_1 = __importDefault(require("handlebars"));
const writeFile = util_1.promisify(fs_1.default.writeFile);
const componentsPath = path_1.default.resolve(process.cwd(), 'src/components');
const pageComponents = fs_1.default.existsSync(componentsPath)
    ? fs_1.default.readdirSync(componentsPath)
    : [];
const containersPath = path_1.default.resolve(process.cwd(), 'src/containers');
const pageContainers = fs_1.default.existsSync(containersPath)
    ? fs_1.default.readdirSync(containersPath)
    : [];
const components = [...pageComponents, ...pageContainers];
function componentExists(comp) {
    return components.indexOf(comp) >= 0;
}
exports.componentExists = componentExists;
handlebars_1.default.registerHelper('properCase', (val) => val.length > 0 ? val[0].toUpperCase() + val.substring(1) : '');
handlebars_1.default.registerHelper('camelCase', (val) => val.length > 0 ? val[0].toLowerCase() + val.substring(1) : '');
handlebars_1.default.registerHelper('curly', (_, open) => (open ? '{' : '}'));
function renderTemplate(template, outPath, context) {
    return __awaiter(this, void 0, void 0, function* () {
        const rendered = handlebars_1.default.compile(template.toString())(context);
        return writeFile(outPath, rendered);
    });
}
exports.renderTemplate = renderTemplate;
function convertTypeArg(type) {
    switch (type) {
        case 'normal':
            return 'React.Component';
        case 'stateless':
            return 'Stateless Function';
        case 'pure':
            return 'React.PureComponent';
        default:
            throw new Error('Unknown type: ' + type);
    }
}
exports.convertTypeArg = convertTypeArg;
//# sourceMappingURL=utils.js.map