#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const tslint_1 = require("tslint");
const typescript_1 = __importDefault(require("typescript"));
class FormatTypescriptHost {
    getCurrentDirectory() {
        return process.cwd();
    }
    getCanonicalFileName(fileName) {
        return fileName;
    }
    getNewLine() {
        return '\n';
    }
}
function lint(fix) {
    const program = tslint_1.Linter.createProgram(path_1.default.resolve(process.cwd(), 'tsconfig.json'), process.cwd());
    const linter = new tslint_1.Linter({
        fix: !!fix,
    }, program);
    const diagnostics = [
        ...program.getSemanticDiagnostics(),
        ...program.getSyntacticDiagnostics(),
    ];
    if (diagnostics.length > 0) {
        console.log(typescript_1.default.formatDiagnosticsWithColorAndContext(diagnostics, new FormatTypescriptHost()));
        process.exit(1);
    }
    for (const file of tslint_1.Linter.getFileNames(program)) {
        const sourceFile = program.getSourceFile(file);
        const content = sourceFile.text;
        const configuration = tslint_1.Configuration.findConfiguration(null, file).results;
        linter.lint(file, content, configuration);
    }
    const results = linter.getResult();
    console.log(results.output);
    return results.errorCount === 0;
}
exports.lint = lint;
if (require.main === module) {
    if (!lint()) {
        process.exit(1);
    }
    else {
        process.exit();
    }
}
//# sourceMappingURL=check.js.map